<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace WP_Rocket\Cli;

use Exception;
use WP_CLI;
use WP_CLI_Command;

/**
 * AccelerateWp CLI commands
 */
class AccelerateWp extends WP_CLI_Command {
	/**
	 * Cdn.
	 *
	 * @param  array $args  args.
	 * @param  array $assoc_args  args.
	 *
	 * @return void
	 * @throws Exception Something went wrong.
	 */
	public function cdn( $args = [], $assoc_args = [] ) {
		$subcommand = '';
		if ( array_key_exists( 0, $args ) ) {
			$subcommand = $args[0];
		}

		if ( ! empty( $subcommand ) && __METHOD__ !== $subcommand && method_exists( $this, $subcommand ) ) {
			$this->$subcommand( $args, $assoc_args );
		} else {
			WP_CLI::error( 'Subcommand not found' );
		}
	}

	/**
	 * Cdn activate.
	 *
	 * @param  array $args  args.
	 * @param  array $assoc_args  args.
	 *
	 * @return void
	 * @throws Exception Something went wrong.
	 */
	private function enable( $args = [], $assoc_args = [] ) {
		try {
			do_action(
				'rocketcdn_accelerate_wp_cli_cdn_enable',
				$assoc_args
			);
			WP_CLI::success( 'Enabled.' );
		} catch ( Exception $e ) {
			$code = $e->getCode() > 0 ? $e->getCode() : 1;
			WP_CLI::error( $e->getMessage(), $code );
		}
	}

	/**
	 * Cdn deactivate.
	 *
	 * @param  array $args  args.
	 * @param  array $assoc_args  args.
	 *
	 * @return void
	 * @throws Exception Something went wrong.
	 */
	private function disable( $args = [], $assoc_args = [] ) {
		try {
			do_action( 'rocketcdn_accelerate_wp_cli_cdn_disable' );
			WP_CLI::success( 'Disabled.' );
		} catch ( Exception $e ) {
			$code = $e->getCode() > 0 ? $e->getCode() : 1;
			WP_CLI::error( $e->getMessage(), $code );
		}
	}
}
